@@ -340,8 +340,7 @@ create_screenshot_frame (GtkWidget   *outer_vbox,
   gtk_box_pack_start (GTK_BOX (hbox), align, FALSE, FALSE, 0);
   gtk_widget_show (align);
 
-  image = gtk_image_new_from_stock (SCREENSHOOTER_ICON,
-                                    GTK_ICON_SIZE_DIALOG);
+  image = gtk_image_new_from_icon_name (SCREENSHOOTER_ICON, GTK_ICON_SIZE_DIALOG);
   gtk_container_add (GTK_CONTAINER (align), image);
   gtk_widget_show (image);
 
@@ -481,7 +480,7 @@ screenshot_interactive_dialog_new (CaptureClickedCallback f, gpointer user_data)
                 NULL);
   if (!shows_app_menu)
     {
-      button = gtk_button_new_from_stock (GTK_STOCK_HELP);
+      button = gtk_button_new_with_mnemonic (_("_Help"));
       g_signal_connect_swapped (button, "clicked", G_CALLBACK (screenshot_display_help), dialog);
       gtk_container_add (GTK_CONTAINER (button_box),
                          button);
